@@ -1,9 +1,9 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.027';
+$Anki::Import::VERSION = '0.028';
 use strict;
 use warnings;
 use Cwd;
-use Getopt::Args 0.1.20;
+use Getopt::Args;
 use Log::Log4perl::Shortcuts 0.021 qw(:all);
 use Exporter qw(import);
 our @EXPORT = qw(anki_import);
@@ -373,7 +373,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 OVERVIEW
 
